# coding: utf-8

"""
    HEP REST API

    The REST API for HEP protocol  # noqa: E501

    OpenAPI spec version: v1
    Contact: xiawu@zeuux.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RetrieveOracleResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'oracle_id': 'str',
        'oracle_name': 'str',
        'public_key': 'str'
    }

    attribute_map = {
        'oracle_id': 'oracle_id',
        'oracle_name': 'oracle_name',
        'public_key': 'public_key'
    }

    def __init__(self, oracle_id=None, oracle_name=None, public_key=None):  # noqa: E501
        """RetrieveOracleResponse - a model defined in Swagger"""  # noqa: E501
        self._oracle_id = None
        self._oracle_name = None
        self._public_key = None
        self.discriminator = None
        self.oracle_id = oracle_id
        self.oracle_name = oracle_name
        self.public_key = public_key

    @property
    def oracle_id(self):
        """Gets the oracle_id of this RetrieveOracleResponse.  # noqa: E501

        The oracle id  # noqa: E501

        :return: The oracle_id of this RetrieveOracleResponse.  # noqa: E501
        :rtype: str
        """
        return self._oracle_id

    @oracle_id.setter
    def oracle_id(self, oracle_id):
        """Sets the oracle_id of this RetrieveOracleResponse.

        The oracle id  # noqa: E501

        :param oracle_id: The oracle_id of this RetrieveOracleResponse.  # noqa: E501
        :type: str
        """
        if oracle_id is None:
            raise ValueError("Invalid value for `oracle_id`, must not be `None`")  # noqa: E501

        self._oracle_id = oracle_id

    @property
    def oracle_name(self):
        """Gets the oracle_name of this RetrieveOracleResponse.  # noqa: E501

        The oracle name  # noqa: E501

        :return: The oracle_name of this RetrieveOracleResponse.  # noqa: E501
        :rtype: str
        """
        return self._oracle_name

    @oracle_name.setter
    def oracle_name(self, oracle_name):
        """Sets the oracle_name of this RetrieveOracleResponse.

        The oracle name  # noqa: E501

        :param oracle_name: The oracle_name of this RetrieveOracleResponse.  # noqa: E501
        :type: str
        """
        if oracle_name is None:
            raise ValueError("Invalid value for `oracle_name`, must not be `None`")  # noqa: E501

        self._oracle_name = oracle_name

    @property
    def public_key(self):
        """Gets the public_key of this RetrieveOracleResponse.  # noqa: E501

        The public key  # noqa: E501

        :return: The public_key of this RetrieveOracleResponse.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this RetrieveOracleResponse.

        The public key  # noqa: E501

        :param public_key: The public_key of this RetrieveOracleResponse.  # noqa: E501
        :type: str
        """
        if public_key is None:
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetrieveOracleResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetrieveOracleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
