# coding: utf-8

"""
    HEP REST API

    The REST API for HEP protocol  # noqa: E501

    OpenAPI spec version: v1
    Contact: xiawu@zeuux.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class NewidResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'newid': 'str',
        'public_key': 'str',
        'main_wallet_address': 'str'
    }

    attribute_map = {
        'newid': 'newid',
        'public_key': 'public_key',
        'main_wallet_address': 'main_wallet_address'
    }

    def __init__(self, newid=None, public_key=None, main_wallet_address=None):  # noqa: E501
        """NewidResponse - a model defined in Swagger"""  # noqa: E501
        self._newid = None
        self._public_key = None
        self._main_wallet_address = None
        self.discriminator = None
        self.newid = newid
        self.public_key = public_key
        self.main_wallet_address = main_wallet_address

    @property
    def newid(self):
        """Gets the newid of this NewidResponse.  # noqa: E501

        The NewID  # noqa: E501

        :return: The newid of this NewidResponse.  # noqa: E501
        :rtype: str
        """
        return self._newid

    @newid.setter
    def newid(self, newid):
        """Sets the newid of this NewidResponse.

        The NewID  # noqa: E501

        :param newid: The newid of this NewidResponse.  # noqa: E501
        :type: str
        """
        if newid is None:
            raise ValueError("Invalid value for `newid`, must not be `None`")  # noqa: E501

        self._newid = newid

    @property
    def public_key(self):
        """Gets the public_key of this NewidResponse.  # noqa: E501

        The hex string of NewID's public key  # noqa: E501

        :return: The public_key of this NewidResponse.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this NewidResponse.

        The hex string of NewID's public key  # noqa: E501

        :param public_key: The public_key of this NewidResponse.  # noqa: E501
        :type: str
        """
        if public_key is None:
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def main_wallet_address(self):
        """Gets the main_wallet_address of this NewidResponse.  # noqa: E501

        The main wallet address of NewChain  # noqa: E501

        :return: The main_wallet_address of this NewidResponse.  # noqa: E501
        :rtype: str
        """
        return self._main_wallet_address

    @main_wallet_address.setter
    def main_wallet_address(self, main_wallet_address):
        """Sets the main_wallet_address of this NewidResponse.

        The main wallet address of NewChain  # noqa: E501

        :param main_wallet_address: The main_wallet_address of this NewidResponse.  # noqa: E501
        :type: str
        """
        if main_wallet_address is None:
            raise ValueError("Invalid value for `main_wallet_address`, must not be `None`")  # noqa: E501

        self._main_wallet_address = main_wallet_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NewidResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewidResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
