# coding: utf-8

"""
    HEP REST API

    The REST API for HEP protocol  # noqa: E501

    OpenAPI spec version: v1
    Contact: xiawu@zeuux.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import hep_rest_api
from models.receipt_field import ReceiptField  # noqa: E501
from hep_rest_api.rest import ApiException


class TestReceiptField(unittest.TestCase):
    """ReceiptField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReceiptField(self):
        """Test ReceiptField"""
        # FIXME: construct object with mandatory attributes with example values
        # model = hep_rest_api.models.receipt_field.ReceiptField()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
